==> sal-wechat-2.11.0-20161212.015434-119-sources.jar: com/baijia/tianxiao/sal/wechat/constant/MediaType.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.wechat.constant;

import org.apache.commons.lang3.StringUtils;

import com.baijia.tianxiao.sal.wechat.constant.webauth.WebAuthScope;
import com.baijia.tianxiao.sal.wechat.dto.mediatype.OrgWechatDto;
import com.baijia.tianxiao.sal.wechat.helper.WechatProperties;
import com.baijia.tianxiao.sal.wechat.helper.webauthlink.WechatWebAuthLinkBuilder;

import lombok.extern.slf4j.Slf4j;

/**
 * @title : WechatMediaType
 * @description :
 * @author : zhenyujian
 * @date : 2015年12月5日 下午6:24:50
 */
@Slf4j
public enum MediaType {

    // 自定义类型 (用于自动回复空对象占位)
    UNKNOWN(0, "", "未知", false, false),

    // 微信的素材类型 (用于微信api str字段为微信接口定义)
    IMAGE(1, "image", "图片", false, false), VOICE(2, "voice", "语音", false, false), VIDEO(3, "video", "视频", false,
        false), THUMB(4, "thumb", "缩略图", false, false), NEWS(5, "news", "图文素材", false, false),

    // 自定义类型
    CONTENT(6, "", "文本", false, false), ZIDINGYILIANJIE(15, "", "自定义链接", true, false),

    WANGXIAOZHUYE(11, "", "网校主页", true, false), KECHENGDANYE(12, "", "课程单页", true, false), HUODONG(13, "", "活动", true,
        false), KECHENGLIEBIAO(14, "", "课程列表", true, false), WODEKEBIAO(16, "", "我的课表", true,
            true), WODEQIANDAO(17, "", "我的签到", true, true), WODEPINGJIA(18, "", "我的评价", true, true),

    WEIGUANWANG(19, "", "微官网", true, false), // 因为android端 也写了一个枚举类 不支持扩展。。 里面的自定义链接类型定死为15
    XIAOQUDIZHI(20, "", "校区地址", true, false), DIANHUA(21, "", "400电话", true, true, true) {
        public String getNote() { // JSONARRAY 会将数字开头的 [400电话] 转为["400电话"],在这里单独处理下
            return "[_400电话]";
        }
    },
    ZAIXIANZIXUN(22, "", "在线咨询", false, false, true),

    YUYUESHITING(23, "", "预约试听", true, false),

    GERENZHONGXIN(24, "", "个人中心", true, true), XUESHENGZHONGXIN(25, "", "学生中心", true, true), LAOSHIZHONGXIN(26, "",
        "老师中心", true, true),

    ;

    public static MediaType getByVaule(int value) {
        for (MediaType type : MediaType.values()) {
            if (type.getValue() == value) {
                return type;
            }
        }
        return null;
    }

    public static MediaType getByLabel(String label) {
        for (MediaType type : MediaType.values()) {
            if (type.getLabel().equals(label)) {
                return type;
            }
        }
        return null;
    }

    private int value;
    private String str;// 微信api key值
    private String label;
    private boolean needUrl;// 是否需要指定url
    private boolean webauth;// 是否需要微信网页授权权限
    private boolean canSetToUnifiedWechat; // 是否可以被修改为统一公众号类型

    private MediaType(int value, String str, String label, boolean needUrl, boolean webauth) {// str字段为微信接口定义
        this(value, str, label, needUrl, webauth, false);
    }

    private MediaType(int value, String str, String label, boolean needUrl, boolean webauth,
        boolean canSetToUnifiedWechat) {// str字段为微信接口定义
        // 只有微信定义的素材类型存在该值
        this.value = value;
        this.str = str;
        this.label = label;
        this.webauth = webauth;
        this.canSetToUnifiedWechat = canSetToUnifiedWechat;
    }

    public int getValue() {
        return this.value;
    }

    public String getStr() {
        return this.str;
    }

    public String getLabel() {
        return this.label;
    }

    public boolean isNeedUrl() {
        return needUrl;
    }

    public void setNeedUrl(boolean needUrl) {
        this.needUrl = needUrl;
    }

    public boolean isWebauth() {
        return webauth;
    }

    public boolean isCanSetToUnifiedWechat() {
        return canSetToUnifiedWechat;
    }

    public void setWebauth(boolean webauth) {
        this.webauth = webauth;
    }

    public String getNote() {
        String fmt = "[%s]";
        return String.format(fmt, this.label);
    }

    public String getUrl(OrgWechatDto orgWechatDto) {
        switch (this) {
            case WANGXIAOZHUYE:
                return this.createCampusWangxiaoZhuYeUrl(orgWechatDto);

            case KECHENGLIEBIAO:
                return this.createCampusCourseListUrl(orgWechatDto);

            case WODEKEBIAO:
                return WechatWebAuthLinkBuilder.schedule(WebAuthScope.BASE, orgWechatDto.getAppId());

            case WODEQIANDAO:
                return WechatWebAuthLinkBuilder.mySigninRecord(WebAuthScope.BASE, orgWechatDto.getAppId());

            case WODEPINGJIA:
                return WechatWebAuthLinkBuilder.rating(WebAuthScope.BASE, orgWechatDto.getAppId());

            case XUESHENGZHONGXIN:
                return WechatWebAuthLinkBuilder.studentCenter(WebAuthScope.BASE, orgWechatDto.getAppId());

            case LAOSHIZHONGXIN:
                return WechatWebAuthLinkBuilder.teacherCenter(WebAuthScope.BASE, orgWechatDto.getAppId());

            case XIAOQUDIZHI:
                return this.createCampusLocatioinUrl(orgWechatDto);

            case YUYUESHITING:
                return this.createCampusYuYueShiTing(orgWechatDto);

            case DIANHUA:
                return createCapmusListUrl(orgWechatDto);

            case ZAIXIANZIXUN:
                return createZaixianZiXun(orgWechatDto);

            default:
                return null;
        }
    }

    public String createZaixianZiXun(OrgWechatDto orgWechatDto) {
        if (orgWechatDto.isUnifiedWechatAccount()) {
            return this.createCapmusListUrl(orgWechatDto);
        } else {
            return "";
        }
    }

    public String createCampusYuYueShiTing(OrgWechatDto orgWechatDto) {
        String fmt4 = "%s%s?orgNumber=%s";
        return String.format(fmt4, WechatProperties.getWebCRMUrlPrefix(), "consult/view.do",
            orgWechatDto.getOrgNumber());
    }

    public String createCampusWangxiaoZhuYeUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} -- createCampusWangxiaoZhuYeUrl", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            StringBuilder mHostBuilder = new StringBuilder(WechatProperties.getWebMTianXiaoUrlPrefix());
            mHostBuilder.append(String.format(WechatProperties.getMhostURLFormat(), orgWechatDto.getOrgNumber()));
            String mHost = mHostBuilder.toString().toString();
            if (!mHost.startsWith("https")) {
                log.info("find http :{} ", mHost);
                mHost = mHost.replace("http", "https");
            }
            return mHost;
        } else {
            String fmt1 = "%s%s%s";
            return String.format(fmt1, WechatProperties.getWebMTianXiaoUrlPrefix(), "i/", orgWechatDto.getOrgNumber());
        }
    }

    public String createCampusCourseListUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCampusCourseListUrl ", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            String mTianxiaoHost = WechatProperties.getWebMTianXiaoUrlPrefix();
            log.info("mTianxiaoHost is :{} ", mTianxiaoHost);
            StringBuilder sbOfCourseList = new StringBuilder(mTianxiaoHost);
            sbOfCourseList
                .append(String.format(WechatProperties.getcampusCourseListUrlFormat(), orgWechatDto.getOrgNumber()));
            return sbOfCourseList.toString();
        } else {
            String fmt2 = "%s%s%s";
            return String.format(fmt2, WechatProperties.getWebMTianXiaoUrlPrefix(), "course/",
                orgWechatDto.getOrgNumber());
        }
    }

    public String createCampusLocatioinUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCampusLocatioinUrl", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            return this.createCapmusListUrl(orgWechatDto);
        } else {
            String fmt3 = "%s%s%s";
            return String.format(fmt3, WechatProperties.getWebMTianXiaoUrlPrefix(), "branch/",
                orgWechatDto.getOrgNumber());
        }
    }

    /**
     * @param orgWechatDto
     * @return
     */
    public String createCapmusListUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCapmusListUrl", orgWechatDto);
        Integer orgNumber = orgWechatDto.getOrgNumber();
        String appId = orgWechatDto.getAppId();
        StringBuilder sb = new StringBuilder(WechatProperties.getWebMTianXiaoUrlPrefix());
        sb.append(String.format(WechatProperties.getCampusListUrlFormat(), orgNumber, appId));
        String campusListUrl = sb.toString();
        if (orgWechatDto.isUnifiedWechatAccount()) {
            campusListUrl = WechatWebAuthLinkBuilder.fansinfo(WebAuthScope.BASE, appId, campusListUrl);
        }
        return campusListUrl;
    }

    public static String fillUrlWithHttp(String url) {
        if (StringUtils.isNotBlank(url)) {
            if (!url.startsWith("http://")) {
                url = "http://" + url;
            }
        }
        return url;
    }
}

==> sal-wechat-2.19.0-20170328.074030-9-sources.jar: com/baijia/tianxiao/sal/wechat/constant/MediaType.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.wechat.constant;

import org.apache.commons.lang3.StringUtils;

import com.baijia.tianxiao.sal.wechat.constant.webauth.WebAuthScope;
import com.baijia.tianxiao.sal.wechat.dto.mediatype.OrgWechatDto;
import com.baijia.tianxiao.sal.wechat.helper.WechatProperties;
import com.baijia.tianxiao.sal.wechat.helper.webauthlink.WechatWebAuthLinkBuilder;

import lombok.extern.slf4j.Slf4j;

/**
 * @author : zhenyujian
 * @title : WechatMediaType
 * @description :
 * @date : 2015年12月5日 下午6:24:50
 */
@Slf4j
public enum MediaType {

    // 自定义类型 (用于自动回复空对象占位)
    UNKNOWN(0, "", "未知", false, false),

    // 微信的素材类型 (用于微信api str字段为微信接口定义)
    IMAGE(1, "image", "图片", false, false),
    VOICE(2, "voice", "语音", false, false),
    VIDEO(3, "video", "视频", false,
            false),
    THUMB(4, "thumb", "缩略图", false, false),
    NEWS(5, "news", "图文素材", false, false),

    // 自定义类型
    CONTENT(6, "", "文本", false, false),
    ZIDINGYILIANJIE(15, "", "自定义链接", true, false),

    WANGXIAOZHUYE(11, "", "网校主页", true, false),
    KECHENGDANYE(12, "", "课程单页", true, false),
    HUODONG(13, "", "活动", true,
            false),
    KECHENGLIEBIAO(14, "", "课程列表", true, false),
    WODEKEBIAO(16, "", "我的课表", true,
            true),
    WODEQIANDAO(17, "", "我的签到", true, true),
    WODEPINGJIA(18, "", "我的评价", true, true),

    WEIGUANWANG(19, "", "微官网", true, false), // 因为android端 也写了一个枚举类 不支持扩展。。 里面的自定义链接类型定死为15
    XIAOQUDIZHI(20, "", "校区地址", true, false),
    DIANHUA(21, "", "400电话", true, true, true) {
        public String getNote() { // JSONARRAY 会将数字开头的 [400电话] 转为["400电话"],在这里单独处理下
            return "[_400电话]";
        }
    },
    ZAIXIANZIXUN(22, "", "在线咨询", false, false, true),

    YUYUESHITING(23, "", "预约试听", true, false),

    GERENZHONGXIN(24, "", "个人中心", true, true),
    XUESHENGZHONGXIN(25, "", "学生中心", true, true),
    LAOSHIZHONGXIN(26, "",
            "老师中心", true, true),;

    public static MediaType getByVaule(int value) {
        for (MediaType type : MediaType.values()) {
            if (type.getValue() == value) {
                return type;
            }
        }
        return null;
    }

    public static MediaType getByLabel(String label) {
        for (MediaType type : MediaType.values()) {
            if (type.getLabel().equals(label)) {
                return type;
            }
        }
        return null;
    }

    private int value;
    private String str;// 微信api key值
    private String label;
    private boolean needUrl;// 是否需要指定url
    private boolean webauth;// 是否需要微信网页授权权限
    private boolean canSetToUnifiedWechat; // 是否可以被修改为统一公众号类型

    private MediaType(int value, String str, String label, boolean needUrl, boolean webauth) {// str字段为微信接口定义
        this(value, str, label, needUrl, webauth, false);
    }

    private MediaType(int value, String str, String label, boolean needUrl, boolean webauth,
                      boolean canSetToUnifiedWechat) {// str字段为微信接口定义
        // 只有微信定义的素材类型存在该值
        this.value = value;
        this.str = str;
        this.label = label;
        this.webauth = webauth;
        this.canSetToUnifiedWechat = canSetToUnifiedWechat;
    }

    public int getValue() {
        return this.value;
    }

    public String getStr() {
        return this.str;
    }

    public String getLabel() {
        return this.label;
    }

    public boolean isNeedUrl() {
        return needUrl;
    }

    public void setNeedUrl(boolean needUrl) {
        this.needUrl = needUrl;
    }

    public boolean isWebauth() {
        return webauth;
    }

    public boolean isCanSetToUnifiedWechat() {
        return canSetToUnifiedWechat;
    }

    public void setWebauth(boolean webauth) {
        this.webauth = webauth;
    }

    public String getNote() {
        String fmt = "[%s]";
        return String.format(fmt, this.label);
    }

    public String getUrl(OrgWechatDto orgWechatDto) {
        switch (this) {
            case WANGXIAOZHUYE:
                String wangXiaoZhuYe = this.createCampusWangxiaoZhuYeUrl(orgWechatDto);
                if (orgWechatDto.isUnifiedWechatAccount()) {
                    wangXiaoZhuYe = WechatWebAuthLinkBuilder.wxIndex(WebAuthScope.BASE, orgWechatDto.getAppId(), wangXiaoZhuYe);
                }
                return wangXiaoZhuYe;

            case KECHENGLIEBIAO:
                return this.createCampusCourseListUrl(orgWechatDto);

            case WODEKEBIAO:
                return WechatWebAuthLinkBuilder.schedule(WebAuthScope.BASE, orgWechatDto.getAppId());

            case WODEQIANDAO:
                return WechatWebAuthLinkBuilder.mySigninRecord(WebAuthScope.BASE, orgWechatDto.getAppId());

            case WODEPINGJIA:
                return WechatWebAuthLinkBuilder.rating(WebAuthScope.BASE, orgWechatDto.getAppId());

            case XUESHENGZHONGXIN:
                return WechatWebAuthLinkBuilder.studentCenter(WebAuthScope.BASE, orgWechatDto.getAppId());

            case LAOSHIZHONGXIN:
                return WechatWebAuthLinkBuilder.teacherCenter(WebAuthScope.BASE, orgWechatDto.getAppId());

            case XIAOQUDIZHI:
                return this.createCampusLocatioinUrl(orgWechatDto);

            case YUYUESHITING:
                return this.createCampusYuYueShiTing(orgWechatDto);

            case DIANHUA:
                return createCapmusListUrl(orgWechatDto);

            case ZAIXIANZIXUN:
                return createZaixianZiXun(orgWechatDto);

            default:
                return null;
        }
    }

    public String createZaixianZiXun(OrgWechatDto orgWechatDto) {
        if (orgWechatDto.isUnifiedWechatAccount()) {
            return this.createCapmusListUrl(orgWechatDto);
        } else {
            return "";
        }
    }

    public String createCampusYuYueShiTing(OrgWechatDto orgWechatDto) {
        String fmt4 = "%s%s?orgNumber=%s";
        return String.format(fmt4, WechatProperties.getWebCRMUrlPrefix(), "consult/view.do",
                orgWechatDto.getOrgNumber());
    }

    public String createCampusWangxiaoZhuYeUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} -- createCampusWangxiaoZhuYeUrl", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            StringBuilder mHostBuilder = new StringBuilder(WechatProperties.getWebMTianXiaoUrlPrefix());
            mHostBuilder.append(String.format(WechatProperties.getMhostURLFormat(), orgWechatDto.getOrgNumber()));
            String mHost = mHostBuilder.toString().toString();
            log.info("find http :{} ", mHost);
            //https不行
            if (!mHost.startsWith("https") && !mHost.contains("test-tianxiao100-m.ctest.baijiahulian.com")) {
                log.info("find http :{} ", mHost);
                mHost = mHost.replace("http", "https");
            }
            return mHost;
        } else {
            String fmt1 = "%s%s%s";
            return String.format(fmt1, WechatProperties.getWebMTianXiaoUrlPrefix(), "i/", orgWechatDto.getOrgNumber());
        }
    }

    public String createCampusCourseListUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCampusCourseListUrl ", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            String mTianxiaoHost = WechatProperties.getWebMTianXiaoUrlPrefix();
            log.info("mTianxiaoHost is :{} ", mTianxiaoHost);
            StringBuilder sbOfCourseList = new StringBuilder(mTianxiaoHost);
            sbOfCourseList
                    .append(String.format(WechatProperties.getcampusCourseListUrlFormat(), orgWechatDto.getOrgNumber()));
            return sbOfCourseList.toString();
        } else {
            String fmt2 = "%s%s%s";
            return String.format(fmt2, WechatProperties.getWebMTianXiaoUrlPrefix(), "course/",
                    orgWechatDto.getOrgNumber());
        }
    }

    public String createCampusLocatioinUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCampusLocatioinUrl", orgWechatDto);
        if (orgWechatDto.isUnifiedWechatAccount()) {
            return this.createCapmusListUrl(orgWechatDto);
        } else {
            String fmt3 = "%s%s%s";
            String httpUrl = getMurlForXiaoqudizhi();
            return String.format(fmt3, httpUrl, "branch/",
                    orgWechatDto.getOrgNumber());
        }
    }

    /**
     * @return
     */
    private String getMurlForXiaoqudizhi() {
        String webMTianXiaoUrlPrefix = WechatProperties.getWebMTianXiaoUrlPrefix();
        if (webMTianXiaoUrlPrefix.startsWith("https:")) {
            return webMTianXiaoUrlPrefix.replace("https", "http");
        }
        return webMTianXiaoUrlPrefix;
    }


    /**
     * @param orgWechatDto
     * @return
     */
    public String createCapmusListUrl(OrgWechatDto orgWechatDto) {
        log.info("orgWechatDto is :{} --createCapmusListUrl", orgWechatDto);
        Integer orgNumber = orgWechatDto.getOrgNumber();
        String appId = orgWechatDto.getAppId();
        StringBuilder sb = new StringBuilder(getMurlForXiaoqudizhi());
        sb.append(String.format(WechatProperties.getCampusListUrlFormat(), orgNumber, appId));
        String campusListUrl = sb.toString();
        if (orgWechatDto.isUnifiedWechatAccount()) {
            campusListUrl = WechatWebAuthLinkBuilder.fansinfo(WebAuthScope.BASE, appId, campusListUrl);
        }
        return campusListUrl;
    }

    public static String fillUrlWithHttp(String url) {
        if (StringUtils.isNotBlank(url)) {
            if (!url.startsWith("http://")) {
                url = "http://" + url;
            }
        }
        return url;
    }
}
